ThinSOS - Python API to the 52North SOS implementation
===================================================================
Still a work in progress...but GetCapabilities, GetDataAvailability, GetFeatureOfInterest, and GetObservation has been implemented.

This package was inspired by `py4sos <https://github.com/manuGil/py4sos>`_.

ThinSOS GitHub repo is here: `https://github.com/Data-to-Knowledge/ThinSOS`_

Installation
------------
ThinSOS can be installed via pip or conda::

  pip install ThinSOS

or::

  conda install -c mullenkamp ThinSOS
